Struct DrawContext
pub struct DrawContext<'a> { /* private fields */ }Expand description
A context for custom drawing.
This is a limited version of the keru_draw [Renderer] that exposes the methods for drawing, but not the internal ones like [Renderer::clear_for_new_frame].
Implementations
impl<'a> DrawContext<'a>
impl<'a> DrawContext<'a>
pub fn draw_image(
&mut self,
image: LoadedImage,
x: f32,
y: f32,
width: f32,
height: f32,
)
pub fn draw_image( &mut self, image: LoadedImage, x: f32, y: f32, width: f32, height: f32, )
Draw an image.
pub fn draw_circle(&mut self, params: Circle)
pub fn draw_circle(&mut self, params: Circle)
Draw a filled circle.
pub fn draw_ring(&mut self, params: CircleRing)
pub fn draw_ring(&mut self, params: CircleRing)
Draw a ring (hollow circle).
pub fn draw_segment(&mut self, params: Segment)
pub fn draw_segment(&mut self, params: Segment)
Draw a line segment.
pub fn draw_triangle(&mut self, params: Triangle)
pub fn draw_triangle(&mut self, params: Triangle)
Draw a triangle.
pub fn draw_hexagon(&mut self, params: Hexagon)
pub fn draw_hexagon(&mut self, params: Hexagon)
Draw a hexagon.
pub fn draw_quadratic_bezier(&mut self, params: QuadraticBezier)
pub fn draw_quadratic_bezier(&mut self, params: QuadraticBezier)
Draw a quadratic bezier curve.
pub fn draw_dashed_box_outline(&mut self, params: DashedBoxOutline)
pub fn draw_dashed_box_outline(&mut self, params: DashedBoxOutline)
Draw a dashed box outline.
pub fn draw_dashed_hexagon_outline(&mut self, params: DashedHexagonOutline)
pub fn draw_dashed_hexagon_outline(&mut self, params: DashedHexagonOutline)
Draw a dashed hexagon outline.
pub fn set_transform(&mut self, transform: Transform)
pub fn set_transform(&mut self, transform: Transform)
Set a transform for subsequent draw calls.
pub fn clear_transform(&mut self)
pub fn clear_transform(&mut self)
Clear the current transform, resetting to identity.
pub fn insert_clip_rect(&mut self, clip_rect: ClipRect) -> ClipRectHandle
pub fn insert_clip_rect(&mut self, clip_rect: ClipRect) -> ClipRectHandle
Create a clip rect for this frame.
pub fn set_clip_rect(&mut self, clip_rect: ClipRect)
pub fn set_clip_rect(&mut self, clip_rect: ClipRect)
Set a clip rect for subsequent draw calls.
pub fn clear_clip_rect(&mut self)
pub fn clear_clip_rect(&mut self)
Clear the current clip rect, resetting to no clip.
pub fn load_svg(
&mut self,
svg_data: &[u8],
width: u32,
height: u32,
) -> Option<LoadedImage>
pub fn load_svg( &mut self, svg_data: &[u8], width: u32, height: u32, ) -> Option<LoadedImage>
Load and rasterize an SVG, returning the loaded image.
Must be unloaded manually with Self::unload_image().
pub fn rerasterize_svg_if_needed(
&mut self,
loaded: &mut LoadedImage,
width: u32,
height: u32,
) -> bool
pub fn rerasterize_svg_if_needed( &mut self, loaded: &mut LoadedImage, width: u32, height: u32, ) -> bool
Rerasterize an SVG at a new size if needed.
pub fn unload_svg(&mut self, loaded: &LoadedImage)
pub fn unload_svg(&mut self, loaded: &LoadedImage)
Remove a loaded SVG and free its atlas space..
Must be unloaded manually with Self::unload_image().
pub fn load_rgba8_image(
&mut self,
rgba_data: &[u8],
width: u32,
height: u32,
) -> Option<LoadedImage>
pub fn load_rgba8_image( &mut self, rgba_data: &[u8], width: u32, height: u32, ) -> Option<LoadedImage>
Load a raster image from raw RGBA8 bytes.
Returns None if the image couldn’t be stored in the atlas..
Must be unloaded manually with Self::unload_image().
pub fn load_encoded_image(&mut self, image_data: &[u8]) -> Option<LoadedImage>
pub fn load_encoded_image(&mut self, image_data: &[u8]) -> Option<LoadedImage>
Load a raster image from encoded bytes (PNG, JPEG, etc.).
Returns None if the image couldn’t be stored in the atlas..
Must be unloaded manually with Self::unload_image().
pub fn unload_image(&mut self, loaded: &LoadedImage)
pub fn unload_image(&mut self, loaded: &LoadedImage)
Remove a loaded image and free its atlas space..
Must be unloaded manually with Self::unload_image().